@@ -2,13 +2,18 @@
 #define GEOJSONSF_GEOMETRYCOLLECTION_H
 
 #include <Rcpp.h>
-#include "geojsonsf/utils/utils.hpp"
 
+#include "sfheaders/utils/utils.hpp"
 
 namespace geojsonsf {
 namespace geometrycollection {
 
-	inline void gc_type( Rcpp::List& sfg, std::string& gc_geom_type, bool& isnull, Rcpp::CharacterVector& cls ) {
+	inline void gc_type(
+			Rcpp::List& sfg,
+			std::string& gc_geom_type,
+			bool& isnull,
+			Rcpp::CharacterVector& cls
+  ) {
 
 		for (Rcpp::List::iterator it = sfg.begin(); it != sfg.end(); it++) {
 
@@ -22,7 +27,7 @@ namespace geometrycollection {
 					gc_geom_type = cls[1];
 
 					SEXP tst = *it;
-					isnull = geojsonsf::utils::is_null_geometry( tst, gc_geom_type );
+					isnull = sfheaders::utils::is_null_geometry( tst, gc_geom_type );
 				} else {
 					gc_type(tmp, gc_geom_type, isnull, cls);
 				}
@@ -36,7 +41,7 @@ namespace geometrycollection {
 					gc_geom_type = cls[1];
 
 					SEXP tst = *it;
-					isnull = geojsonsf::utils::is_null_geometry( tst, gc_geom_type );
+					isnull = sfheaders::utils::is_null_geometry( tst, gc_geom_type );
 				}
 				break;
 			}
@@ -50,12 +55,4 @@ namespace geometrycollection {
 } // namespace geometrycollection
 } // namespace geojsonsf
 
-
-// for backwards compability until spatialwidget v0.2 is on CRAN
-template< typename Writer >
-inline void make_gc_type(Writer& writer, Rcpp::List& sfg,
-                         std::string& geom_type, Rcpp::CharacterVector& cls){
-  Rcpp::stop("");
-};
-
 #endif
